@@ -1,4 +1,4 @@
-/* $Id: bogoutil.c 6920 2010-07-05 20:05:57Z relson $ */
+/* $Id: bogoutil.c 6993 2013-06-28 21:54:23Z m-a $ */
 
 /*****************************************************************************
 
@@ -50,8 +50,8 @@ const char *progname = "bogoutil";
 
 static int token_count = 0;
 
-bool  maintain = false;
-bool  onlyprint = false;
+static bool maintain = false;
+static bool onlyprint = false;
 
 /* Function Definitions */
 
@@ -620,7 +620,7 @@ static int process_arglist(int argc, char **argv)
 	int this_option_optind = optind ? optind : 1;
 	const char *name;
 
-	option = getopt_long(argc, argv, OPTIONS,
+	option = getopt_long_chk(argc, argv, OPTIONS,
 			     longopts_bogoutil, &option_index);
 
 	if (option == -1)
