@@ -1,4 +1,4 @@
-/* $Id: convert_unicode.c 6402 2005-12-31 09:56:18Z m-a $ */
+/* $Id: convert_unicode.c 6888 2010-03-14 16:24:40Z m-a $ */
 
 /*****************************************************************************
 
@@ -33,7 +33,7 @@ AUTHOR:
 #define	SP	' '
 
 #include <iconv.h>
-iconv_t cd = NULL;
+iconv_t cd = (iconv_t)-1;
 
 static void map_nonascii_characters(void)
 {
@@ -106,11 +106,11 @@ static charset_def_t charsets[] = {
     { "csgb2312",	T },
 };
 
-iconv_t *bf_iconv_open( const char *to_charset, const char *from_charset )
+iconv_t bf_iconv_open( const char *to_charset, const char *from_charset )
 {
-    iconv_t *xd = iconv_open( to_charset, from_charset );
+    iconv_t xd = iconv_open( to_charset, from_charset );
 
-    if (xd == (iconv_t)(-1)) {
+    if (xd == (iconv_t)-1) {
 	int err = errno;
 	if (err == EINVAL) {
 	    if (DEBUG_ICONV(1))
@@ -120,9 +120,6 @@ iconv_t *bf_iconv_open( const char *to_charset, const char *from_charset )
 	    xd = iconv_open( charset_unicode, charset_default );
 	}
     }
-  
-    if (xd == (iconv_t)(-1))
-	xd = NULL;
 
     return xd;
 }
@@ -131,7 +128,7 @@ void init_charset_table_iconv(const char *from_charset, const char *to_charset)
 {
     uint idx;
 
-    if (cd != NULL)
+    if (cd != (iconv_t)-1)
 	iconv_close(cd);
 
     if (DEBUG_ICONV(1))
