@@ -1,4 +1,4 @@
-/* $Id: format.h 6704 2008-02-24 11:33:47Z m-a $ */
+/* $Id: format.h 6789 2009-02-12 01:12:53Z relson $ */
 
 #ifndef FORMAT_H
 #define FORMAT_H
@@ -36,5 +36,6 @@ extern bool set_spamicity_fields(FIELD *strings, const char *val);
 extern char *format_header(char *buff, size_t size);
 extern char *format_terse(char *buff, size_t size);
 extern char *format_log_header(char *buff, size_t size);
-extern char *format_log_update(char *buff, size_t size, const char *reg, const char *unreg, uint wordcount, uint msgcount);
+extern void  format_set_counts(uint _wrd, uint _msg);
+extern char *format_log_update(char *buff, size_t size, const char *reg, const char *unreg);
 #endif
