@@ -1,4 +1,4 @@
-/* $Id: globals.h 6777 2009-02-01 03:49:48Z relson $ */
+/* $Id: globals.h 6940 2010-12-21 01:20:22Z relson $ */
 
 #ifndef GLOBALS_H
 #define GLOBALS_H
@@ -77,9 +77,6 @@ extern	uint		 msgs_bad;
 extern size_t msg_register_size;
 extern char msg_register[256];
 
-extern bool maintain;
-extern bool onlyprint;
-
 /*		    old     new
 **  robs            0.010   0.0178
 **  robx            0.415   0.52
@@ -114,9 +111,6 @@ extern	uint	db_cachesize;
 
 extern FILE  *fpo;
 
-enum passmode { PASS_MEM, PASS_SEEK };
-extern enum passmode passmode;
-
 extern	bool	msg_count_file;
 extern	bool	unsure_stats;	/* true if print stats for unsures */
 
